import { ElementRef, TemplateRef } from '@angular/core';
import { Identifier, ListSchema, TableSchema } from '@lightweightform/storage';
import { VirtualScrollComponent } from '@lightweightform/virtual-scroll';
import { InlineValue } from '../../abstract/inline-value';
import { TableHeaderDirective } from '../../directives/table-header/table-header.directive';
import { ActionsMenuAction } from '../actions-menu/actions-menu.component';
/**
 * HTML string of the table component.
 */
export declare const tableComponentHtml: string;
/**
 * Default width of the selection column (in `px`).
 */
export declare const SELECTION_COLUMN_WIDTH = 25.6;
/**
 * LF table component.
 */
export declare class TableComponent extends InlineValue {
    /**
     * Height (in `px`) of a single row (virtual scroll settings). All rows must
     * have the same height.
     */
    rowHeight: number;
    /**
     * Maximum number of visible rows at any given time (virtual scroll settings).
     */
    maxVisibleRows: number;
    /**
     * Number of "excess" rows rendered before and after the visible rows (virtual
     * scroll settings).
     */
    excessRows: number;
    _tableHeader: TableHeaderDirective;
    rowTemplate: TemplateRef<any>;
    noRowsTemplate: TemplateRef<any>;
    _headerTableContainer: ElementRef;
    _bodyTableContainer: ElementRef;
    _virtualScroll: VirtualScrollComponent;
    private _selectedRows;
    private _lastSelectedId;
    private _disposeScroll;
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    readonly addRowText: string;
    readonly removeRowsText: string;
    readonly noRowsText: string;
    readonly columnLabels: string[];
    columnLabel(columnId: string): string;
    /**
     * Schema of this table's value.
     */
    readonly schema: ListSchema | TableSchema;
    /**
     * Table's value.
     */
    readonly value: any[];
    /**
     * Whether to show the "is required" icon on the component.
     */
    readonly showIsRequired: boolean;
    readonly _tableActions: ActionsMenuAction[];
    numberOfColumns(includeScrollbarColumn: boolean): number | null;
    tableMinWidth(includeScrollbarColumn: boolean): number | null;
    tableMaxWidth(includeScrollbarColumn: boolean): number | null;
    columnWidths(includeScrollbarColumn: boolean): string[];
    readonly verticalScrollbarWidth: number;
    readonly isEditable: boolean;
    readonly numberOfRowsSelected: number;
    readonly allRowsSelected: boolean;
    readonly noRowsSelected: boolean;
    /**
     * Track either by index or reference, depending on the type of value for list
     * schemas; or by row id, when dealing with table schemas.
     */
    readonly _trackBy: (index: number, value: any) => any;
    /**
     * Identifier of the given element with the given index.
     * @param el Element for which to get identifier.
     * @param index Index of the element in the value.
     * @returns Identifier for the given element at the given index.
     */
    id(el: any, index: number): Identifier;
    getRowSelectedStatus(id: Identifier): boolean;
    pushRow(): void;
    setRowSelectedStatus(id: Identifier, selectedStatus: boolean): void;
    setRowSelectedStatusFromLastSelected(id: Identifier, selectedStatus: boolean): void;
    unselectAllRows(): void;
    setAllRowsSelectedStatus(selectedStatus: boolean): void;
    toggleAllRowsSelectedStatus(): void;
    removeSelectedRows(): void;
    _onClickRemoveRows(): void;
    _onClickNewRow(): void;
    /**
     * @override
     */
    protected validatePath(): void;
    /**
     * Scroll to the activated row when one is activated.
     * @override
     */
    protected onActivate(activatedPath: string): void;
}
